# $Id: ja.rb,v 1.14 2005/07/14 01:50:25 fdiary Exp $
# Copyright (C) 2002-2003 TAKEUCHI Hitoshi <hitoshi@namaraii.com>
# You can redistribute it and/or modify it under the terms of
# the Ruby's licence.
module Hiki
  module Messages_ja
    def msg_recent; '' end
    def msg_create; '' end
    def msg_diff; 'ʬ' end
    def msg_edit; 'Խ' end
    def msg_search; '' end
    def msg_admin; '' end
    def msg_login; '' end
    def msg_logout; '' end
    def msg_search_result; '' end
    def msg_search_hits; '\'%s\'ޤڡ%dڡ桢%dڡĤޤ' end
    def msg_search_not_found; '\'%s\'ޤڡϸĤޤǤ' end
    def msg_search_comment; 'ƤΥڡñ򸡺ޤʸȾʸ϶̤ޤȾѥڡñڤȻꤷñƴޤڡ򸡺ޤ' end
    def msg_frontpage; 'ȥå' end
    def msg_hitory; '' end
    def msg_index; 'ڡ' end
    def msg_recent_changes; '' end
    def msg_newpage; '' end
    def msg_no_recent; '<P>¸ߤޤ</P>' end
    def msg_thanks; '꤬Ȥޤ' end
    def msg_save_conflict; 'ͤޤƤƥȥǥʤɤ¸ǿΥڡ򻲾ȸ˺ԽƤ' end
    def msg_time_format; "%Y-%m-%d #DAY# %H:%M:%S" end
    def msg_date_format; "%Y-%m-%d " end
    def msg_day; %w(      ) end
    def msg_preview; 'ʲΥץӥ塼ǧ꤬ʤХڡβˤ¸ܥ¸Ƥ <a href="#form">Խե</a>' end
    def msg_mail_on; '᡼' end
    def msg_mail_off; '' end
    def msg_use; 'Ѥ' end
    def msg_unuse; 'Ѥʤ' end
    def msg_login_info; 'ԤȤƥ󤹤ݤϡ桼̾ admin ϤƤ' end
    def msg_login_failure; '桼̾ޤϥѥɤְäƤޤ' end
    def msg_name; '桼̾' end
    def msg_password; 'ѥ' end
    def msg_ok; 'OK' end
    def msg_invalid_password; 'ѥɤְäƤޤޤ¸Ƥޤ' end
    def msg_save_config; '¸ޤ' end
    def msg_freeze; 'Υڡ뤵Ƥޤ¸ˤϴѤΥѥɤɬפǤ' end
    def msg_freeze_mark; '' end
    def msg_already_exist; 'ΥڡϤǤ¸ߤƤޤ' end
    def msg_page_not_exist; 'Υڡ¸ߤޤ󡣤ҡƤ:-)' end
    def msg_invalid_filename(s); "ʸޤޤƤ뤫Ĺ(#{s}Х)ĶƤޤڡ̾Ƥ" end
    def msg_delete; 'ڡޤ' end
    def msg_delete_page; 'ʲΥڡޤ' end
    def msg_follow_link; 'ʲΥ󥯤򤿤ɤäƤ: ' end
    def msg_match_title; '[ȥ˰]' end
    def msg_match_keyword; '[ɤ˰]' end
    def msg_duplicate_page_title; 'ꤷȥϴ¸ߤƤޤ' end
    def msg_missing_anchor_title; 'ڡ %s 򿷵Խޤ' end
    # (config)
    def msg_config; 'Hiki Ķ'; end
    # (diff)
    def msg_diff_add; 'Ǹιɲä줿ʬ<ins class="added">Τ褦</ins>ɽޤ'; end
    def msg_diff_del; 'ǸιǺ줿ʬ<del class="deleted">Τ褦</del>ɽޤ'; end
    # (edit)
    def msg_title; 'ȥ'; end
    def msg_keyword_form; '(1Ԥ1ĵҤƤ)'; end
    def msg_freeze_checkbox; 'ڡ'; end
    def msg_preview_button; 'ץӥ塼'; end
    def msg_save; '¸'; end
    def msg_update_timestamp; 'ॹפ򹹿'; end
    def msg_latest; 'ǿǤ򻲾'; end
    def msg_rules; %Q|狼ʤ<a href="#{@cgi_name}?TextFormattingRules">TextFormattingRules</a>򻲾ȤƤ|; end
    # (view)
    def msg_last_modified; ''; end
    def msg_keyword; ''; end
    def msg_reference; ''; end
  end
end
